@@ -1,10 +1,10 @@
 # coding: utf-8
 from contextlib import contextmanager
 from functools  import wraps
+import six
 import sys
 
 
-
 __all__ = ("contextdecorator", "nested", "RequestFactory")
 
 
@@ -100,7 +100,6 @@ def contextdecorator(yielder):
     return thing
 
 
-
 @contextmanager
 def nested(*managers):
     exc = None, None, None
@@ -121,7 +120,7 @@ def nested(*managers):
             except:
                 exc = sys.exc_info()
         if exc != (None, None, None):
-            raise exc[0], exc[1], exc[2]
+            six.reraise(*exc)
 
 
 try:
